==> jc-1.4.0.tar.gz: polyglot/frontend/TargetFactory.h <==
// public class polyglot.frontend.TargetFactory

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c99629f926ef2e3f polyglot_frontend_TargetFactory

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_frontend_TargetFactory_H_
#define _JC_polyglot_frontend_TargetFactory_H_

// Forward structure declarations
struct _jc_java_io_File$object;
struct _jc_java_io_Writer$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_polyglot_frontend_Source$object;

// Typedefs
typedef struct _jc_polyglot_frontend_TargetFactory$sub_refs	_jc_polyglot_frontend_TargetFactory$sub_refs;
typedef struct _jc_polyglot_frontend_TargetFactory$sub_nonrefs	_jc_polyglot_frontend_TargetFactory$sub_nonrefs;
typedef struct _jc_polyglot_frontend_TargetFactory$refs	_jc_polyglot_frontend_TargetFactory$refs;
typedef struct _jc_polyglot_frontend_TargetFactory$nonrefs	_jc_polyglot_frontend_TargetFactory$nonrefs;
typedef struct _jc_polyglot_frontend_TargetFactory$object	_jc_polyglot_frontend_TargetFactory$object;

typedef const struct _jc_polyglot_frontend_TargetFactory$vmethods	_jc_polyglot_frontend_TargetFactory$vmethods;
typedef const struct _jc_polyglot_frontend_TargetFactory$vtable	_jc_polyglot_frontend_TargetFactory$vtable;
typedef const struct _jc_polyglot_frontend_TargetFactory$vtype	_jc_polyglot_frontend_TargetFactory$vtype;

// Constructors
extern void _jc_polyglot_frontend_TargetFactory$method$_init$aa8534e7e8807714(_jc_env *, struct _jc_polyglot_frontend_TargetFactory$object *, struct _jc_java_io_File$object *, struct _jc_java_lang_String$object *, jboolean);

// Virtual methods
extern struct _jc_java_io_File$object *_jc_polyglot_frontend_TargetFactory$method$outputFile$d78934d4d9797553(_jc_env *, struct _jc_polyglot_frontend_TargetFactory$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, struct _jc_polyglot_frontend_Source$object *);
extern struct _jc_java_io_File$object *_jc_polyglot_frontend_TargetFactory$method$outputFile$d841c7f40915a70a(_jc_env *, struct _jc_polyglot_frontend_TargetFactory$object *, struct _jc_java_lang_String$object *, struct _jc_polyglot_frontend_Source$object *);
extern struct _jc_java_io_Writer$object *_jc_polyglot_frontend_TargetFactory$method$outputWriter$d25a01a68d960754(_jc_env *, struct _jc_polyglot_frontend_TargetFactory$object *, struct _jc_java_io_File$object *);
extern struct _jc_java_io_Writer$object *_jc_polyglot_frontend_TargetFactory$method$outputWriter$38df3d82c3b2b709(_jc_env *, struct _jc_polyglot_frontend_TargetFactory$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, struct _jc_polyglot_frontend_Source$object *);

// Virtual method descriptors
extern _jc_method _jc_polyglot_frontend_TargetFactory$method_info$outputFile$d78934d4d9797553;
extern _jc_method _jc_polyglot_frontend_TargetFactory$method_info$outputFile$d841c7f40915a70a;
extern _jc_method _jc_polyglot_frontend_TargetFactory$method_info$outputWriter$d25a01a68d960754;
extern _jc_method _jc_polyglot_frontend_TargetFactory$method_info$outputWriter$38df3d82c3b2b709;

// Virtual methods structure
struct _jc_polyglot_frontend_TargetFactory$vmethods {
	struct _jc_java_io_File$object	*(*outputFile$d78934d4d9797553)(_jc_env *, struct _jc_polyglot_frontend_TargetFactory$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, struct _jc_polyglot_frontend_Source$object *);
	struct _jc_java_io_File$object	*(*outputFile$d841c7f40915a70a)(_jc_env *, struct _jc_polyglot_frontend_TargetFactory$object *, struct _jc_java_lang_String$object *, struct _jc_polyglot_frontend_Source$object *);
	struct _jc_java_io_Writer$object	*(*outputWriter$d25a01a68d960754)(_jc_env *, struct _jc_polyglot_frontend_TargetFactory$object *, struct _jc_java_io_File$object *);
	struct _jc_java_io_Writer$object	*(*outputWriter$38df3d82c3b2b709)(_jc_env *, struct _jc_polyglot_frontend_TargetFactory$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, struct _jc_polyglot_frontend_Source$object *);
};

// Vtable
struct _jc_polyglot_frontend_TargetFactory$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_frontend_TargetFactory$vmethods	polyglot_frontend_TargetFactory;
};

// Vtype
struct _jc_polyglot_frontend_TargetFactory$vtype {
	_jc_type			type;
	_jc_polyglot_frontend_TargetFactory$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_frontend_TargetFactory$sub_refs {
	struct _jc_java_io_File$object	*outputDirectory;
	struct _jc_java_lang_String$object	*outputExtension;
};

// Reference instance fields (object)
struct _jc_polyglot_frontend_TargetFactory$refs {
    _jc_polyglot_frontend_TargetFactory$sub_refs	polyglot_frontend_TargetFactory;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_frontend_TargetFactory$sub_nonrefs {
	jboolean	outputStdout;
};

// Non-reference instance fields (object)
struct _jc_polyglot_frontend_TargetFactory$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_frontend_TargetFactory$sub_nonrefs	polyglot_frontend_TargetFactory;
};

// Object instance structure
struct _jc_polyglot_frontend_TargetFactory$object {
	_jc_polyglot_frontend_TargetFactory$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_frontend_TargetFactory$vtype	*vtype;
	_jc_polyglot_frontend_TargetFactory$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_frontend_TargetFactory$vtype _jc_polyglot_frontend_TargetFactory$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_frontend_TargetFactory, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_frontend_TargetFactory$class_object;

#endif	/* _JC_polyglot_frontend_TargetFactory_H_ */

==> jc-1.4.6.tar.gz: polyglot/frontend/TargetFactory.h <==
// public class polyglot.frontend.TargetFactory

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class c99629f926ef2e3f polyglot_frontend_TargetFactory

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_frontend_TargetFactory_H_
#define _JC_polyglot_frontend_TargetFactory_H_

// Forward structure declarations
struct _jc_java_io_File$object;
struct _jc_java_io_Writer$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_polyglot_frontend_Source$object;

// Typedefs
typedef struct _jc_polyglot_frontend_TargetFactory$sub_refs	_jc_polyglot_frontend_TargetFactory$sub_refs;
typedef struct _jc_polyglot_frontend_TargetFactory$sub_nonrefs	_jc_polyglot_frontend_TargetFactory$sub_nonrefs;
typedef struct _jc_polyglot_frontend_TargetFactory$refs	_jc_polyglot_frontend_TargetFactory$refs;
typedef struct _jc_polyglot_frontend_TargetFactory$nonrefs	_jc_polyglot_frontend_TargetFactory$nonrefs;
typedef struct _jc_polyglot_frontend_TargetFactory$object	_jc_polyglot_frontend_TargetFactory$object;

typedef const struct _jc_polyglot_frontend_TargetFactory$vmethods	_jc_polyglot_frontend_TargetFactory$vmethods;
typedef const struct _jc_polyglot_frontend_TargetFactory$vtable	_jc_polyglot_frontend_TargetFactory$vtable;
typedef const struct _jc_polyglot_frontend_TargetFactory$vtype	_jc_polyglot_frontend_TargetFactory$vtype;

// Constructors
extern void _jc_polyglot_frontend_TargetFactory$method$_init$aa8534e7e8807714(_jc_env *, struct _jc_polyglot_frontend_TargetFactory$object *, struct _jc_java_io_File$object *, struct _jc_java_lang_String$object *, jboolean) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_io_File$object *_jc_polyglot_frontend_TargetFactory$method$outputFile$d78934d4d9797553(_jc_env *, struct _jc_polyglot_frontend_TargetFactory$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, struct _jc_polyglot_frontend_Source$object *) _JC_JCNI_ATTR;
extern struct _jc_java_io_File$object *_jc_polyglot_frontend_TargetFactory$method$outputFile$d841c7f40915a70a(_jc_env *, struct _jc_polyglot_frontend_TargetFactory$object *, struct _jc_java_lang_String$object *, struct _jc_polyglot_frontend_Source$object *) _JC_JCNI_ATTR;
extern struct _jc_java_io_Writer$object *_jc_polyglot_frontend_TargetFactory$method$outputWriter$d25a01a68d960754(_jc_env *, struct _jc_polyglot_frontend_TargetFactory$object *, struct _jc_java_io_File$object *) _JC_JCNI_ATTR;
extern struct _jc_java_io_Writer$object *_jc_polyglot_frontend_TargetFactory$method$outputWriter$38df3d82c3b2b709(_jc_env *, struct _jc_polyglot_frontend_TargetFactory$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, struct _jc_polyglot_frontend_Source$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_polyglot_frontend_TargetFactory$method_info$outputFile$d78934d4d9797553;
extern _jc_method _jc_polyglot_frontend_TargetFactory$method_info$outputFile$d841c7f40915a70a;
extern _jc_method _jc_polyglot_frontend_TargetFactory$method_info$outputWriter$d25a01a68d960754;
extern _jc_method _jc_polyglot_frontend_TargetFactory$method_info$outputWriter$38df3d82c3b2b709;

// Virtual methods structure
struct _jc_polyglot_frontend_TargetFactory$vmethods {
	struct _jc_java_io_File$object	*(*outputFile$d78934d4d9797553)(_jc_env *, struct _jc_polyglot_frontend_TargetFactory$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, struct _jc_polyglot_frontend_Source$object *) _JC_JCNI_ATTR;
	struct _jc_java_io_File$object	*(*outputFile$d841c7f40915a70a)(_jc_env *, struct _jc_polyglot_frontend_TargetFactory$object *, struct _jc_java_lang_String$object *, struct _jc_polyglot_frontend_Source$object *) _JC_JCNI_ATTR;
	struct _jc_java_io_Writer$object	*(*outputWriter$d25a01a68d960754)(_jc_env *, struct _jc_polyglot_frontend_TargetFactory$object *, struct _jc_java_io_File$object *) _JC_JCNI_ATTR;
	struct _jc_java_io_Writer$object	*(*outputWriter$38df3d82c3b2b709)(_jc_env *, struct _jc_polyglot_frontend_TargetFactory$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, struct _jc_polyglot_frontend_Source$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_polyglot_frontend_TargetFactory$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_frontend_TargetFactory$vmethods	polyglot_frontend_TargetFactory;
};

// Vtype
struct _jc_polyglot_frontend_TargetFactory$vtype {
	_jc_type			type;
	_jc_polyglot_frontend_TargetFactory$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_frontend_TargetFactory$sub_refs {
	struct _jc_java_io_File$object	*outputDirectory;
	struct _jc_java_lang_String$object	*outputExtension;
};

// Reference instance fields (object)
struct _jc_polyglot_frontend_TargetFactory$refs {
    _jc_polyglot_frontend_TargetFactory$sub_refs	polyglot_frontend_TargetFactory;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_frontend_TargetFactory$sub_nonrefs {
	jboolean	outputStdout;
};

// Non-reference instance fields (object)
struct _jc_polyglot_frontend_TargetFactory$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_frontend_TargetFactory$sub_nonrefs	polyglot_frontend_TargetFactory;
};

// Object instance structure
struct _jc_polyglot_frontend_TargetFactory$object {
	_jc_polyglot_frontend_TargetFactory$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_frontend_TargetFactory$vtype	*vtype;
	_jc_polyglot_frontend_TargetFactory$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_frontend_TargetFactory$vtype _jc_polyglot_frontend_TargetFactory$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_frontend_TargetFactory, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_frontend_TargetFactory$class_object;

#endif	/* _JC_polyglot_frontend_TargetFactory_H_ */
